import { bold } from 'chalk';
import consola from 'consola';
import defu from 'defu';
import { readJSONSync } from 'fs-extra';
import { resolve, join } from 'upath';

var name = "@nuxtjs/sanity";
var version = "0.9.0";

const isProd = process.env.NODE_ENV === "production";
const DEFAULTS = {
  contentHelper: true,
  imageHelper: true,
  dataset: "production",
  apiVersion: "1",
  withCredentials: false,
  additionalClients: {}
};
const CONFIG_KEY = "sanity";
function validateConfig({projectId, dataset}) {
  if (!projectId) {
    consola.warn(`Make sure you specify a ${bold("projectId")} in your sanity config.`);
    return false;
  } else {
    consola.info(`Enabled ${bold("@nuxtjs/sanity")} for project ${bold(projectId)} (${bold(dataset)}).`);
    return true;
  }
}
const sanityModule = function sanityModule2(moduleOptions) {
  let sanityConfig = {};
  try {
    const {projectId, dataset} = readJSONSync(resolve(this.options.rootDir, "./sanity.json")).api;
    sanityConfig = {projectId, dataset};
  } catch (e) {
  }
  const options = defu(this.options[CONFIG_KEY], moduleOptions, sanityConfig, {useCdn: isProd && !moduleOptions.token && (!this.options[CONFIG_KEY] || !this.options[CONFIG_KEY].token)}, DEFAULTS);
  if (!validateConfig(options)) {
    return;
  }
  try {
    if (!options.minimal) {
      options.minimal = !this.nuxt.resolver.requireModule("@sanity/client");
    }
  } catch (e) {
    options.minimal = true;
    consola.warn(`Not using ${bold("@sanity/client")} as it cannot be resolved in your project dependencies.
       Try running ${bold("yarn add @sanity/client")} or ${bold("npm install @sanity/client")}.
       To disable this warning, set ${bold("sanity: { minimal: true }")} in your nuxt.config.js.`);
  }
  this.options[CONFIG_KEY] = options;
  const autoregister = !!this.options.components;
  this.addPlugin({
    src: resolve(__dirname, "../templates/plugin.js"),
    fileName: "sanity/plugin.js",
    options: {
      client: !options.minimal,
      components: {
        autoregister,
        imageHelper: options.imageHelper,
        contentHelper: options.contentHelper
      },
      sanityConfig: JSON.stringify({
        useCdn: options.useCdn,
        projectId: options.projectId,
        dataset: options.dataset,
        apiVersion: options.apiVersion,
        withCredentials: options.withCredentials,
        token: options.token
      }),
      additionalClients: JSON.stringify(options.additionalClients)
    }
  });
  if (autoregister) {
    this.nuxt.hook("components:dirs", (dirs) => {
      dirs.push({
        path: join(__dirname, "components"),
        extensions: ["js"]
      });
    });
  }
  this.options.build.transpile = this.options.build.transpile || [];
  this.options.build.transpile.push(/^@nuxtjs[\\/]sanity/);
};
sanityModule.meta = {name, version};

export default sanityModule;
export { CONFIG_KEY };
