'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const chalk = require('chalk');
const consola = require('consola');
const defu = require('defu');
const fsExtra = require('fs-extra');
const upath = require('upath');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

const consola__default = /*#__PURE__*/_interopDefaultLegacy(consola);
const defu__default = /*#__PURE__*/_interopDefaultLegacy(defu);

var name = "@nuxtjs/sanity";
var version = "0.9.0";

const isProd = process.env.NODE_ENV === "production";
const DEFAULTS = {
  contentHelper: true,
  imageHelper: true,
  dataset: "production",
  apiVersion: "1",
  withCredentials: false,
  additionalClients: {}
};
const CONFIG_KEY = "sanity";
function validateConfig({projectId, dataset}) {
  if (!projectId) {
    consola__default['default'].warn(`Make sure you specify a ${chalk.bold("projectId")} in your sanity config.`);
    return false;
  } else {
    consola__default['default'].info(`Enabled ${chalk.bold("@nuxtjs/sanity")} for project ${chalk.bold(projectId)} (${chalk.bold(dataset)}).`);
    return true;
  }
}
const sanityModule = function sanityModule2(moduleOptions) {
  let sanityConfig = {};
  try {
    const {projectId, dataset} = fsExtra.readJSONSync(upath.resolve(this.options.rootDir, "./sanity.json")).api;
    sanityConfig = {projectId, dataset};
  } catch (e) {
  }
  const options = defu__default['default'](this.options[CONFIG_KEY], moduleOptions, sanityConfig, {useCdn: isProd && !moduleOptions.token && (!this.options[CONFIG_KEY] || !this.options[CONFIG_KEY].token)}, DEFAULTS);
  if (!validateConfig(options)) {
    return;
  }
  try {
    if (!options.minimal) {
      options.minimal = !this.nuxt.resolver.requireModule("@sanity/client");
    }
  } catch (e) {
    options.minimal = true;
    consola__default['default'].warn(`Not using ${chalk.bold("@sanity/client")} as it cannot be resolved in your project dependencies.
       Try running ${chalk.bold("yarn add @sanity/client")} or ${chalk.bold("npm install @sanity/client")}.
       To disable this warning, set ${chalk.bold("sanity: { minimal: true }")} in your nuxt.config.js.`);
  }
  this.options[CONFIG_KEY] = options;
  const autoregister = !!this.options.components;
  this.addPlugin({
    src: upath.resolve(__dirname, "../templates/plugin.js"),
    fileName: "sanity/plugin.js",
    options: {
      client: !options.minimal,
      components: {
        autoregister,
        imageHelper: options.imageHelper,
        contentHelper: options.contentHelper
      },
      sanityConfig: JSON.stringify({
        useCdn: options.useCdn,
        projectId: options.projectId,
        dataset: options.dataset,
        apiVersion: options.apiVersion,
        withCredentials: options.withCredentials,
        token: options.token
      }),
      additionalClients: JSON.stringify(options.additionalClients)
    }
  });
  if (autoregister) {
    this.nuxt.hook("components:dirs", (dirs) => {
      dirs.push({
        path: upath.join(__dirname, "components"),
        extensions: ["js"]
      });
    });
  }
  this.options.build.transpile = this.options.build.transpile || [];
  this.options.build.transpile.push(/^@nuxtjs[\\/]sanity/);
};
sanityModule.meta = {name, version};

exports.CONFIG_KEY = CONFIG_KEY;
exports.default = sanityModule;
